@@ -13,12 +13,12 @@
 # limitations under the License.
 
 import logging
-import os
 import platform
 import sys
 
 import click
 import stackprinter
+from datahub.cli.cli_utils import get_boolean_env_variable
 from prometheus_client import start_http_server
 
 import datahub_actions as datahub_package
@@ -95,7 +95,7 @@ def datahub_actions(
     # 3. Turn off propagation to the root handler.
     datahub_logger.propagate = False
     # 4. Adjust log-levels.
-    if debug or os.getenv("DATAHUB_DEBUG", False):
+    if debug or get_boolean_env_variable("DATAHUB_DEBUG", False):
         logging.getLogger().setLevel(logging.INFO)
         datahub_logger.setLevel(logging.DEBUG)
     else:
